@@ -4,19 +4,20 @@
 ## usethis namespace: start
 #' @import checkmate
 #' @import stringr
-#' @import glue
 #' @import utils
-#' @import SqlRender
-#' @import fs
 #' @import dplyr
 #' @import Andromeda
 #' @import R6
-#' @importFrom data.table data.table
+#' @import sunburstR
+#' @import networkD3
+#' @importFrom htmlwidgets JS
 #' @importFrom stats sd median
 #' @importFrom tidyr pivot_wider
 #' @importFrom googleVis gvisSankey
 #' @importFrom rjson toJSON
 #' @importFrom stringi stri_replace_all_fixed
-#' @importFrom DatabaseConnector connect disconnect querySql
 ## usethis namespace: end
 NULL
+
+# Global Variables
+utils::globalVariables(c("x", "y", "rowNumber", "path"))
